ent = {}

ents = {}

--ent_size = 8
ent_fade = 1500
ent_speed = 6000
ent_acc = 100
ent_f = 4

ent_type = {
		coin = {size = 8, decay = 5, c = {255, 200, 0}},
		health = {size = 16, decay = 3, c = {255, 0, 200}},
		ammo = {size = 16, decay = 3, c = {0, 130, 0}}
	}

--Shader canvas
local shdata = love.image.newImageData(1, 1)
for y=0, shdata:getHeight() - 1 do
	for x=0, shdata:getWidth() - 1 do
		shdata:setPixel(x, y, 255, 255, 255, 255)
	end
end
local sh = love.graphics.newImage(shdata)

function ent.reset()
	for i,v in ipairs(ents) do
		table.remove(ents, i)
	end
end

function ent.spawn(t, dx, dy, a, r)
	local range = {
			x = dx - r,
			y = dy - r,
			s = r * 3
		}
		
	for i=1, a do
		local x = math.random(range.x, range.x + range.s)
		local y = math.random(range.y, range.y + range.s)
		
		if y + t.size > screen.h - world.ground_h then
			y = screen.h - t.size - world.ground_h
		end
		ents[#ents + 1] = {
				x = x,
				y = y,
				xVel = math.random(-50, 50),
				yVel = 0,
				a = 255,
				del = false,
				air = true,
				t = t,
				size = t.size,
				d = t.decay,
				c = t.c
			}
		end
end

function ent.update(dt)
	if #ents > 0 then
		for i,v in ipairs(ents) do
			--Ground Collision
			if not checkCollision(v.x, v.y, v.size, v.size, 0, screen.h - world.ground_h, screen.w, world.ground_h) then
				v.yVel = v.yVel + world.gravity * dt
				v.air = true
			else
				v.yVel = -(v.yVel / 4)
				v.y = screen.h - v.size - world.ground_h
				v.air = false
			end
			
			--x movement
			if v.x + (v.size / 2) < player.x + (player.w / 2) then
					v.xVel = ent_speed / getDistance(player.x+ (player.w / 2), player.y + (player.h / 2), v.x, v.y)
			else
				v.xVel = -(ent_speed / getDistance(player.x + (player.w / 2), player.y + (player.h / 2), v.x, v.y))
			end
			
			v.xVel = v.xVel * (1 - math.min(dt*ent_f, 1))
			
			--position update
			v.x = v.x + v.xVel * dt
			v.y = v.y + v.yVel * dt
			
			--Player Collision
			if checkCollision(v.x, v.y, v.size, v.size, player.x, player.y, player.w, player.h) then		
				v.del = true
			end
			
			if v.del then
				v.a = v.a - ent_fade * dt
				if v.a < 0 then
					if v.t == ent_type.coin then
						player.money = player.money + 1
					elseif v.t == ent_type.health then
						local h = math.random(20, 40)
						player.health.c = player.health.c + h
						if player.health.c > player.health.m then
							player.health.c = player.health.m
						end
						note.new("Added "..h.." to health", color_white)
					elseif v.t == ent_type.ammo then
						local h = math.random(5, 15)
						player.ammo.c = player.ammo.c + h
						if player.ammo.c > player.ammo.m then
								player.ammo.c = player.ammo.m
						end
						note.new("Added "..h.." to Ammo", color_white)
					end
					
					table.remove(ents, i)					
				end
			end
		end
	end
end

function ent.draw()
	for i,v in ipairs(ents) do
		love.graphics.setColor(v.c[1], v.c[2], v.c[3], v.a)
		shaders.light.set()
		love.graphics.draw(sh, v.x, v.y)
		love.graphics.rectangle("fill", v.x, v.y, v.size, v.size)
		
		local al = v.a - 200
		if al < 0 then
			al = 0
		end
		love.graphics.setColor(v.c[1], v.c[2], v.c[3], al)

		local ry = (screen.h - world.ground_h) - v.size + (screen.h - world.ground_h) - v.y
		love.graphics.rectangle("fill", v.x, ry, v.size, v.size)
		
		shaders.clear()
	end
end