obj = {}

local tick = 0
local int = 1
	
o = {} --spawned objects
obj_size = 32
obj_maxVel = 300
obj_spawnEnabled = true

--Shader canvas
local shdata = love.image.newImageData(1, 1)
for y=0, shdata:getHeight() - 1 do
	for x=0, shdata:getWidth() - 1 do
		shdata:setPixel(x, y, 255, 255, 255, 255)
	end
end
local sh = love.graphics.newImage(shdata)

function obj.spawn(x, y, t)
		o[#o + 1] = {
				x = x,
				y = y,
				xVel = 0,
				yVel = 0,
				t = t,
				air = true,
				ti = {c = 1.5, t = 1.5},--time before removed
				a = 255,
				die = {b = false, c = "none"} -- death and cause
			}
end

function obj.reset()
	for i,v in ipairs(o) do
		table.remove(o, i)
	end
	tick = 0
end

function obj.update(dt)
	--obj spawn
	if obj_spawnEnabled then
		tick = tick + dt
		if tick > int then
			local x = math.random(0, screen.w - obj_size)
			local n = math.random(0, 100)
			local t = 1
			if n < 60 then
				t = 1
			else
				t = 2
			end
			obj.spawn(x, -obj_size, t)
			
			tick = 0
		end
	end
	
	--Obj update
	for i,v in ipairs(o) do
		--GENERAL UPDATES
		--Gravity
		if v.yVel < obj_maxVel then	
			v.yVel = v.yVel + world.gravity * dt
		else
			v.yVel = obj_maxVel
		end
		local py = v.y + v.yVel * dt
		
		--Ground Collision
		if py + obj_size > screen.h - world.ground_h then
			v.yVel = -(v.yVel / 2)
			py = screen.h - obj_size - world.ground_h
			v.air = false
			v.ti.c = v.ti.c - dt
			if v.ti.c < 0 then
				v.die.b = true
				v.die.c = "time"
			end
		else
			v.air = true
		end
		
		--player collision
		if checkCollision(v.x, v.y, obj_size, obj_size, player.x, player.y, player.w, player.h) then
			--basic
			if not v.die.b then
				v.die.b = true
				v.die.c = "player"
				
				--class specific
				if v.t == 1 then
					player.health.c = player.health.c - math.random(10, 30)
				elseif v.t == 2 then
					ent.spawn(ent_type.coin, v.x, v.y, math.random(4, 8), 64)
					local o = math.random(0, 100)
					if o < 30 then
						local r = math.random(0, 100)
						if r < 40 then
							ent.spawn(ent_type.health, v.x, v.y, 1, 64)
						else
							ent.spawn(ent_type.ammo, v.x, v.y, 1, 64)
						end
					end
				end
				
				--Player Effects
			end
		end
		
		--Bullet collision
		for p,b in ipairs(bullets) do
			if not v.die.b then
				if b.x > v.x and b.x < v.x + obj_size and b.y > py and b.y < py + obj_size then
					table.remove(bullets, p)
					v.die.b = true
					v.die.c = "bullet"
				
					if v.t == 1 then -- red
						local r = math.random(0, 100)
						if r < 30 then
							ent.spawn(ent_type.coin, v.x, v.y, math.random(2, 4), 64)
							local d = math.random(0, 100)			
							if d < 40 then
								ent.spawn(ent_type.health, v.x, v.y, 1, 64)
							else
								ent.spawn(ent_type.ammo, v.x, v.y, 1, 64)
							end
						else
							ent.spawn(ent_type.coin, v.x, v.y, math.random(4, 8), 64)
						end
					elseif v.t == 2 then
						ent.spawn(ent_type.coin, v.x, v.y, math.random(1, 2), 64)
					end
				end
			end
		end
		
		--REMOVAL
		if v.die.b then
			if v.die.c == "time" then
				v.a = v.a - 400 * dt
			elseif v.die.c == "bullet" or v.die.c == "player" then
				v.a = v.a - 1000 * dt
			end
			
			if v.a < 0 then
				table.remove(o, i)
			end
		end
		v.y = py
	end
end

function obj.draw(dt)
	--love.graphics.draw(bg)
	--shaders.light.size = 0.01
	for i,v in ipairs(o) do
		shaders.light.set()
		if v.t == 1 then
			love.graphics.setColor(120, 0, 0, v.a)
		elseif v.t == 2 then
			love.graphics.setColor(0, 180, 0, v.a)
		end
		love.graphics.draw(sh, v.x, v.y)
		love.graphics.rectangle("fill", v.x, v.y, obj_size, obj_size)
		--Ref
		local al = v.a - 200
		if al < 0 then
			al = 0
		end
		if v.t == 1 then
			love.graphics.setColor(120, 0, 0, al)
		elseif v.t == 2 then
			love.graphics.setColor(0, 180, 0, al)
		end
		local ry = (screen.h - world.ground_h) - obj_size + (screen.h - world.ground_h) - v.y
		love.graphics.rectangle("fill", v.x, ry, obj_size, obj_size)
		
		shaders.clear()
		
	end
end

















