player = {
		x = 0,
		y = 0,
		w = 32,
		h = 32,
		xVel = 0,
		yVel = 0,
		s = 500,--X speed
		acc = {
				c = 400,
				ground = 800,
				air = 400
			},
		maxVel = 600,--Maximum Velocity
		air = true,
		friction = {
				c = 1,
				ground = 2,
				air = 1
			},
		jumpStr = 400,
		health = {c = 200, m = 200},
		money = 0,
		shooting = {c = 0, i = 0.15} ,
		ammo = {c = 100, m = 100},
		
		focus = {c = 100, m = 100, ds = 40, rs = 10} -- slow motion mode
	}
	
bullets = {}
bullet_speed = 800

function player.reset()
	player.x = screen.w / 2 - (player.w / 2)
	player.y = screen.h - player.w - world.ground_h
	player.xVel = 0
	player.yVel = 0
	player.money = 0
	player.health.c = player.health.m
	player.ammo.c = player.ammo.m
end

function player.update(dt)
	if debug_playermouse then
		player.x = love.mouse.getX() - (player.w / 2)
		player.y = love.mouse.getY() - (player.h / 2)
	else
		--Player X Movement
		if love.keyboard.isDown("d") or love.keyboard.isDown("right") then
			if player.xVel < player.s then
				player.xVel = player.xVel + player.acc.c * dt
			else
				player.xVel = player.s
			end
		elseif love.keyboard.isDown("a") or love.keyboard.isDown("left") then
			if player.xVel > -player.s then
				player.xVel = player.xVel - player.acc.c * dt
			else
				player.xVel = -player.s
			end
		end
		--Friction
		player.xVel = player.xVel * (1 - math.min(dt*player.friction.c, 1))
		
		--Gravity
		if player.yVel < player.maxVel then
			player.yVel = player.yVel + world.gravity * dt
		end
		
		--AND COLLISION
		local px = player.x + player.xVel * dt --Pseudo x position
		local py = player.y + player.yVel * dt --Pseudo y position
		
		--X COLLISION
		--wall
		if px < 0 then
			player.xVel = -(player.xVel / 4)
			px = 0
		elseif px > screen.w - player.w then
			player.xVel = -(player.xVel / 4)
			px = screen.w - player.w
		end
		
		--Y COLLISION
		--ground
		if py + player.h > screen.h - world.ground_h then --GROUND
			player.yVel = 0
			--player.yVel = -(player.yVel / 4)
			py = screen.h - world.ground_h - player.h
			player.air = false
			player.friction.c = player.friction.ground
			player.acc.c = player.acc.ground
		else	--AIR
			player.air = true
			player.friction.c = player.friction.air
			player.acc.c = player.acc.air
		end
		
		--position update
		player.x = px
		player.y = py
		
		--Shooting
		if love.mouse.isDown("l") then
			player.shooting.c = player.shooting.c + dt
			if player.shooting.c > player.shooting.i then
				if player.ammo.c > 0 then
					player.shoot()
				end
				player.shooting.c = 0
			end
		else
			player.shooting.c = player.shooting.i - 0.001
		end
		
		--Focus
		if love.keyboard.isDown("lshift") or love.keyboard.isDown("rshift") then
			if player.focus.c > 0 then
				slow = true
				player.focus.c = player.focus.c - player.focus.ds * (dt * 4)
			else
				slow = false
			end
			
		else
			slow = false
			player.focus.c = player.focus.c + player.focus.rs * dt
			if player.focus.c > player.focus.m then
				player.focus.c = player.focus.m
			end
		end
		
		--BULLET UPDATEd
		for i,v in ipairs(bullets) do
			v.x = v.x + math.sin(math.rad(v.a)) * bullet_speed * dt
			v.y = v.y + math.cos(math.rad(v.a)) * bullet_speed * dt
			
			--collision
			if v.y < 0 or v.x < 0 or v.x > screen.w then
				table.remove(bullets, i)
			end
		end
	end
end

function player.shoot(x, y)
	local x, y = love.mouse.getPosition()
	bullets[#bullets + 1] = {
			x = player.x + (player.w / 2),
			y = player.y + (player.h / 2),
			a = 0
		}
		local a = getAngle(player.x + (player.w / 2), player.y + (player.h / 2), x, y)
		local side = "none"
		if not player.air then
			if a < 180 and a > 0 then
				side = "r"
			elseif a > -180 and a < 0 then
				side = "l"
			end
			
			if side == "r" then
				if a < 90 then
					a = 90
				end
			elseif side == "l" then
				if a > -90 then
					a = -90
				end
			end
		end
		
		player.ammo.c = player.ammo.c - 1
		
		bullets[#bullets].a = a
end

function player.draw()
	--bullets
	love.graphics.setColor(255, 255, 255, 255)
	for i,v in ipairs(bullets) do
		love.graphics.circle("fill", v.x, v.y, 2, 8)
	end
	
	--Player
	love.graphics.setColor(0, 180, 180, 255)
	love.graphics.rectangle("fill", player.x, player.y, player.w, player.h)
	
	--Player Reflection
	local ry = (screen.h - world.ground_h) - player.h + (screen.h - world.ground_h) - player.y
	
	love.graphics.setColor(0, 180, 180, 100)
	love.graphics.rectangle("fill", player.x, ry, player.w, player.h)
	
	--DEBUG
	if debug_enabled then
		if debug_lines then
			love.graphics.setColor(255, 0, 0, 50)
			for i,v in ipairs(o) do
				love.graphics.line(player.x + (player.w / 2), player.y + (player.w / 2), v.x + (obj_size / 2), v.y + (obj_size / 2))
			end
		end
	end
end

function player.keypressed(key)
	if key == "w" or key == "up" then
		if not player.air then
			player.y = player.y - 1
			player.yVel = -player.jumpStr
		end
	end
	
	if debug_enabled then
		if key == "l" then
			debug_lines = not debug_lines
		end
	end
end

function player.mousepressed(x, y, k)
	if k == "l" then

	end
end

